/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/*
 * Ulozte kopii tohoto souboru jako userChrome.css do adresare chrome 
 * v adresari s uzivatelskym profilem a upravte dle vasich predstav.
 *  
 * Tento soubor se pouziva k nastaveni nekterych vychytavek uzivatelskeho 
 * rozhrani prohlizece Firefox. Pravidla s deklaraci !important prevazi 
 * nad vychozimi pravidly definovanymi ve stylech UI.
 * 
 * Nasleduji radku NEODSTRANUJTE 
 * 
 */
@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

/*
 * Priklad: Nastavte vsechny pisma na 20 pt:
 * * { font-size: 20pt !important }
 *
 * Priklad: Nastavte pismo v nabidce na 15pt
 * menupopup > * { font-size: 15pt !important }
 *
 * Priklad: Zmenete rodinu pisma v radku s adresou
 * #urlbar { font-family: monospace !important; }
 * 
 * Vice prikladu naleznete na http://www.mozilla.org/unix/customizing.html
 *
 */
 
