/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/*
 * Ulozte kopii tohoto souboru jako userContent.css do adresare chrome 
 * v adresari s uzivatelskym profilem a upravte dle vasich predstav.
 * 
 * Tento soubor se pouziva k nastaveni uzivatelskych kaskadovych stylu
 * na webovych strankach. Pravidla bez deklarace !important budou prepsana
 * kaskadovymi styly webove stranky, pokud takove jsou. Pravidla s deklaraci
 * !important prevazi nad pravidly na webove strance.
 *
 * priklad: odstranit blikajici prvky
 * blink { text-decoration: none !important; }
 *
 * priklad: nastavit vsem tabulkam cerny ramecek 2px siroky
 * table { border: 2px black solid; }
 *
 * priklad: nastavit prvky #q na strance www.mozilla.org
 * @-moz-document url-prefix(http://www.mozilla.org/) {
 *   #q { background: white ! important; color: black ! important; }
 * }
 *
 * Vice prikladu naleznete na http://www.mozilla.org/unix/customizing.html
 *
 */

